/* $Workfile: OsaCon.h $   $Revision: 12 $    $Modtime: 12/17/03 4:53p $  */
#ifndef OSA_CON_H
#define OSA_CON_H
/*******************************************************************************

  @doc PublicHwApi OsaCon

  Copyright (C) 1999-2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OsaCon | This file contains prototypes for platform the generic 
  implementation of some console functions.

  @contents2
  OsaCon.h |

  @index func | OsaCon

  @contents2
  Generic Console Functions - OsaConsoleXXX() | A platform generic 
  implementation of some console functions.
  
  @head3 OsaConsoleXXX() Function Reference |

  @index func | OsaCon

*******************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif

#if defined(__linux__)

#include <stdarg.h>
#if 1
#include <ncurses.h>
#else
#include <stdio.h>
#define getch getchar
#endif

#elif defined(_WIN32_WCE)
#include <windows.h>

#elif defined(WIN32)
#include <windows.h>
#include <conio.h>

#else
#error "Platform not supported"

#endif


/******************************************************************************

  @func
    Initialize the platform generic Osa Console functions.

  @comm
    This function must be called before any other Osa function can be called. 
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleExit>

******************************************************************************/
void OTX_API OsaConsoleInit(void);


/******************************************************************************

  @func
    Exit the platform generic functions.

  @comm
    This function should be called before exiting the application if 
    <f OsaConsoleInit> was called.

    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>

******************************************************************************/
void OTX_API OsaConsoleExit(void);


/******************************************************************************

  @func
    Platform generic Osa implementation of the standard printf() function.

  @comm
    Osa functions are used by the demo programs.

******************************************************************************/
int OTX_API OsaConsolePrintF(
  char *formatStr,          // @parm Format string. See printf() in stdio.h
  va_list argList           // @parm Argument list. See printf() in stdio.h
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the standard printf() function.

  @comm
    Osa functions are used by the demo programs.

******************************************************************************/
void _OsaConsolePrintF(
  char *formatStr,          // @parm Format string. See printf() in stdio.h
  ...
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the standard gets() function.

  @comm
    Osa functions are used by the demo programs.

******************************************************************************/
char * OTX_API OsaConsoleGetStr(
  char *buffer              // @parm Placeholder for input string. See gets() in stdio.h
);


/******************************************************************************

  @func
    Platform generic Osa implementation of a standard beep() function.

  @comm
    Osa functions are used by the demo programs.

******************************************************************************/
void OTX_API OsaBeep(
  unsigned int Freq,        // @parm sound frequency, in hertz
  unsigned int msDuration   // @parm sound duration, in milliseconds
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the standard puts() function.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleInit>

******************************************************************************/
int OTX_API OsaConsolePutStr(
  char *buffer              // @parm Placeholder for input string. See puts() in stdio.h
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the standard getch() function.

  @comm
    Osa functions are used by the demo programs.

******************************************************************************/
int OTX_API OsaConsoleGetCh(
  void
);


/******************************************************************************

  @func
    Provides an alternative input stream to the console functions other
    than from the keyboard buffer. The string passed to this function will be 
    fed to <f OsaConsoleGetStr> and <f OsaConsoleGetCh>. 
    
    To indicate an 'Enter' key in the <f OsaConsoleGetStr> function, use 
    the '^' character in the parameter to this function.

  @comm
    Osa functions are used by the demo programs.

  @xref
    <f OsaConsoleGetStr>
    <f OsaConsoleGetCh>

******************************************************************************/
void OTX_API OsaConsoleInput(
  char *inputStr
);



#ifdef __cplusplus
  } // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999-2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif // OSA_CON_H

